--TRAINS
--stdOpen is for vanilla and vanilla-like open waggons
--stdBox  is for vanilla and vanilla-like boxcars
--stdTank is for vanilla and vanilla-like tank waggons
--stdFlat is for vanilla and vanilla-like flat waggons / stake cars

local stdOpen = {"COAL", "IRON_ORE", "STONE", "GRAIN", "SLAG"}
local stdBox = {"LIVESTOCK", "PLASTIC", "MACHINES", "TOOLS", "FOOD", "GOODS"}
local stdTank = {"CRUDE", "OIL", "FUEL"}
local stdFlat = {"LOGS", "STEEL", "PLANKS", "CONSTRUCTION_MATERIALS"}
local waggons = {stdOpen, stdBox, stdTank, stdFlat}
local waggonPerUnitPrice = {250 --[[stdOpen]], 250 --[[stdBox]], 300 --[[stdTank]], 200 --[[stdFlat]]}
local waggonRunningModifier = {1 --[[stdOpen]], 1 --[[stdBox]], 1 --[[stdTank]], 1 --[[stdFlat]]}
local global = {waggonPerUnitPrice = 1, waggonRunningModifier = 1/5}
function inList(list, value)
	for i = 1, #list do
		if list[i] == value then return true end
	end
	return false
end

function canCarryAll(capacities, list)
	counter = 0
	for i = 1, #capacities do
		if inList(list, capacities[i].type) then
			counter = counter + 1
		end
	end
	if counter == #capacities then return {true, capacities[1].capacity}
	else return {false, 0} end
end

local function modelCallback(fileName, data)
	--[[if data.metadata.transportVehicle then
		if data.metadata.transportVehicle.capacities then
			if not data.metadata.transportVehicle.multipleUnitOnly and data.metadata.railVehicle and not data.metadata.railVehicle.engines then
				if data.metadata.transportVehicle.capacities[1].type == "PASSENGERS" then
					data.metadata.cost.price = data.metadata.transportVehicle.capacities[1].capacity * 10
				end
			end
		end
	end]]--
	if data.metadata.railVehicle and data.metadata.transportVehicle then
		if data.metadata.transportVehicle.capacities then
			for i = 1, #waggons do
				waggon = canCarryAll(data.metadata.transportVehicle.capacities, waggons[i])
				if waggon[1] then
					data.metadata.cost.price = waggon[2] * waggonPerUnitPrice[i] * data.metadata.railVehicle.weight * global.waggonPerUnitPrice
					data.metadata.maintenance.runningCosts = data.metadata.cost.price * waggonRunningModifier[i] * global.waggonRunningModifier
				end
			end
		end
	end
	return data
end


--TRACK and BRIDGE
local stdTrackPriceModifier = 1
local stdHighSpdPriceModifier = 1
local globalTrackPriceModifier = 5
local steelBidgePriceModifier = 1
local concreteBidgePriceModifier = 1
local stoneBidgePriceModifier = 1
local woodenBidgePriceModifier = 1
local globalBridgePriceModifier = 10
local tunnelPriceModifier = 20
local function costCallback(fileName, data)
	if data.name == _("Standard tracks") then
		data.cost = data.cost * stdTrackPriceModifier * globalTrackPriceModifier
	elseif data.name == _("High-speed tracks") then
		data.cost = data.cost * stdHighSpdPriceModifier * globalTrackPriceModifier	
	elseif data.name == _("Steel bridge") then
		data.cost = data.cost * steelBidgePriceModifier * globalBridgePriceModifier
	elseif data.name == _("Concrete bridge") then
		data.cost = data.cost * concreteBidgePriceModifier * globalBridgePriceModifier
	elseif data.name == _("Stone bridge") then
		data.cost = data.cost * stoneBidgePriceModifier * globalBridgePriceModifier
	elseif data.name == _("Wooden bridge") then
		data.cost = data.cost * woodenBidgePriceModifier * globalBridgePriceModifier
	elseif data.name == _("Standard tunnel") then
		data.cost = data.cost * tunnelPriceModifier
	--else data.cost = data.cost * globalTrackPriceModifier
	end
	return data
end

local stdDepotPriceModifier = 25
local stdRailStationCargoPriceModifier = 10
local stdRailStationPriceModifier = 10
local stdDepotRunning = 2500
local stdRailStationCargoRunningModifier = 10
local stdRailStationRunningModifier = 10
local globalBuildingPriceModifier = 1
local globalBuildingRunningModifier = 1
local stdIndustryPrice = {[_("Chemical plant")] = {1, 1},
								  [_("Coal mine")] = {1, 1},
								  [_("Construction materials plant")] = {1, 1},
								  [_("Farm")] = {1, 1},
								  [_("Food processing plant")] = {1, 1},
								  [_("Forest")] = {1, 1},
								  [_("Goods factory")] = {1, 1},
								  [_("Iron ore mine")] = {1, 1},
								  [_("Machine factory")] = {1, 1},
								  [_("Oil refinery")] = {1, 1},
								  [_("Oil well")] = {1, 1},
								  [_("Quarry")] = {1, 1},
								  [_("Saw mill")] = {1, 1},
								  [_("Steel mill")] = {100000, 1000},
								  }
local globalIndustryPriceModifier = 1
local globalIndustryRunningModifier = 1
local function constructionCallback(fileName, data)
	local fn = data.updateFn
	data.updateFn = function(params)
		local result = fn(params)
		if data.type == "RAIL_DEPOT" then
			result.cost = result.cost * stdDepotPriceModifier * globalBuildingPriceModifier
			result.maintenanceCost = stdDepotRunning * globalBuildingRunningModifier
		elseif data.type == "RAIL_STATION_CARGO" then
			result.cost = result.cost * stdRailStationCargoPriceModifier * globalBuildingPriceModifier
			result.maintenanceCost = result.maintenanceCost * stdRailStationCargoRunningModifier * globalBuildingRunningModifier
		elseif data.type == "RAIL_STATION" then
			result.cost = result.cost * stdRailStationPriceModifier * globalBuildingPriceModifier
			result.maintenanceCost = result.maintenanceCost * stdRailStationRunningModifier * globalBuildingRunningModifier
		elseif data.type == "INDUSTRY" then
			result.cost = stdIndustryPrice[data.description.name][1] * (params.productionLevel + 1) * globalIndustryPriceModifier
			result.maintenanceCost = stdIndustryPrice[data.description.name][2] * (params.productionLevel + 1) * globalIndustryRunningModifier
		end	
		return result
	end
	return data
end

--TRACK CATENARY
local stdRRcatenaryModifier = 0.5 -- fraction of road/track cost

function data()
return {
	info = {
		minorVersion = 0,
		severityAdd = "NONE",
		severityRemove = "NONE",
		name = _("Test_2"),
		description = _("Test_2"),
	},
	runFn = function (settings)
		addModifier("loadModel", modelCallback)
		addModifier("loadTrack", costCallback)
		addModifier("loadConstruction", constructionCallback)
		addModifier("loadBridge", costCallback)
		addModifier("loadTunnel", costCallback)
		game.config.costs.railroadCatenary = stdRRcatenaryModifier
	end
}
end
